@@ -2,7 +2,8 @@ import odmlib.odm_element as OE
 import odmlib.typed as T
 import odmlib.ns_registry as NS
 
-NS.NamespaceRegistry(prefix="odm", uri="http://www.cdisc.org/ns/odm/v2.0", is_default=True)
+
+NS.NamespaceRegistry(prefix="odm", uri="http://www.cdisc.org/ns/odm/v1.3", is_default=True)
 NS.NamespaceRegistry(prefix="xs", uri="http://www.w3.org/2001/XMLSchema-instance")
 NS.NamespaceRegistry(prefix="xml", uri="http://www.w3.org/XML/1998/namespace")
 NS.NamespaceRegistry(prefix="xlink", uri="http://www.w3.org/1999/xlink")
@@ -10,21 +11,16 @@ NS.NamespaceRegistry(prefix="xlink", uri="http://www.w3.org/1999/xlink")
 
 class TranslatedText(OE.ODMElement):
     lang = T.String(namespace="xml")
-    Type = T.String()
     _content = T.String(required=True)
 
 
-class Description(OE.ODMElement):
-    TranslatedText = T.ODMListObject(required=True, element_class=TranslatedText)
-
-
 class Alias(OE.ODMElement):
     Context = T.String(required=True)
     Name = T.String(required=True)
 
 
 class StudyDescription(OE.ODMElement):
-    Description = T.ODMObject(element_class=Description, required=True)
+    _content = T.String(required=True)
 
 
 class ProtocolName(OE.ODMElement):
@@ -35,11 +31,36 @@ class StudyName(OE.ODMElement):
     _content = T.String(required=True)
 
 
+class GlobalVariables(OE.ODMElement):
+    StudyName = T.ODMObject(element_class=StudyName)
+    StudyDescription = T.ODMObject(element_class=StudyDescription)
+    ProtocolName = T.ODMObject(element_class=ProtocolName)
+
+
+class Symbol(OE.ODMElement):
+    TranslatedText = T.ODMListObject(required=True, element_class=TranslatedText)
+
+
+class MeasurementUnit(OE.ODMElement):
+    OID = T.OID(required=True)
+    Name = T.Name(required=True)
+    Symbol = T.ODMObject(required=True, element_class=Symbol)
+    Alias = T.ODMListObject(element_class=Alias)
+
+
+class BasicDefinitions(OE.ODMElement):
+    MeasurementUnit = T.ODMListObject(element_class=MeasurementUnit)
+
+
 class Include(OE.ODMElement):
     StudyOID = T.OIDRef(required=True)
     MetaDataVersionOID = T.OIDRef(required=True)
 
 
+class Description(OE.ODMElement):
+    TranslatedText = T.ODMListObject(required=True, element_class=TranslatedText)
+
+
 class StudyEventRef(OE.ODMElement):
     StudyEventOID = T.OID(required=True)
     OrderNumber = T.Integer(required=False)
@@ -53,16 +74,21 @@ class Protocol(OE.ODMElement):
     Alias = T.ODMListObject(element_class=Alias)
 
 
+class FormRef(OE.ODMElement):
+    FormOID = T.OID(required=True)
+    OrderNumber = T.Integer(required=False)
+    Mandatory = T.ValueSetString(required=True)
+    CollectionExceptionConditionOID = T.OIDRef()
+
+
 class StudyEventDef(OE.ODMElement):
-    """ represents ODM v2.0 StudyEventDef and can serialize as JSON or XML """
     OID = T.OID(required=True)
     Name = T.Name(required=True)
     Repeating = T.ValueSetString(required=True)
     Type = T.ValueSetString(required=True)
     Category = T.String(required=False)
     Description = T.ODMObject(element_class=Description)
-    ItemGroupRef = T.ODMListObject(element_class=ItemGroupRef)
-    WorkflowRef = T.ODMListObject(element_class=WorkflowRef)
+    FormRef = T.ODMListObject(element_class=FormRef)
     Alias = T.ODMListObject(element_class=Alias)
 
     def __len__(self):
@@ -70,9 +96,7 @@ class StudyEventDef(OE.ODMElement):
         return len(self.FormRef)
 
     def __getitem__(self, position):
-        """
-        creates an iterator from an StudyEventDef object that returns the FormRef in position
-        """
+        """ creates an iterator from an StudyEventDef object that returns the FormRef in position """
         return self.FormRef[position]
 
     def __iter__(self):
@@ -92,6 +116,15 @@ class ArchiveLayout(OE.ODMElement):
     PresentationOID = T.OIDRef(required=False)
 
 
+class FormDef(OE.ODMElement):
+    OID = T.OID(required=True)
+    Name = T.Name(required=True)
+    Repeating = T.ValueSetString(required=True)
+    Description = T.ODMObject(element_class=Description)
+    ItemGroupRef = T.ODMListObject(element_class=ItemGroupRef)
+    ArchiveLayout = T.ODMListObject(element_class=ArchiveLayout)
+    Alias = T.ODMListObject(element_class=Alias)
+
     def __len__(self):
         return len(self.ItemGroupRef)
 
@@ -102,39 +135,6 @@ class ArchiveLayout(OE.ODMElement):
         return iter(self.ItemGroupRef)
 
 
-class PDFPageRef(OE.ODMElement):
-    Type = T.ValueSetString(required=True)
-    PageRefs = T.String()
-    FirstPage = T.PositiveInteger()
-    LastPage = T.PositiveInteger()
-
-
-class DocumentRef(OE.ODMElement):
-    leafID = T.String(required=True)
-    PDFPageRef = T.ODMListObject(element_class=PDFPageRef, namespace="def")
-
-
-class SourceItem(OE.ODMElement):
-    leadID = T.IDRef()
-    ItemGroupOID = T.OIDRef()
-    Resource = T.String()
-    Attribute = T.String()
-    Path = T.String()
-    Label = T.String()
-
-
-class SourceItems(OE.ODMElement):
-    SourceItem = T.ODMListObject(element_class=SourceItem, required=True)
-
-
-class Origin(OE.ODMElement):
-    Type = T.ValueSetString(required=True)
-    Source = T.ValueSetString()
-    DocumentRef = T.ODMListObject(element_class=DocumentRef, namespace="def")
-    Description = T.ODMObject(element_class=Description)
-    SourceItems = T.ODMObject(element_class=SourceItems)
-
-
 class ItemRef(OE.ODMElement):
     ItemOID = T.String(required=True)
     OrderNumber = T.Integer(required=False)
@@ -147,21 +147,17 @@ class ItemRef(OE.ODMElement):
 
 
 class ItemGroupDef(OE.ODMElement):
-    """ represents ODM v2.0 ItemGroupDef and can serialize as JSON or XML"""
     OID = T.OID(required=True)
     Name = T.Name(required=True)
     Repeating = T.ValueSetString(required=True)
-    Type = T.ValueSetString()
     IsReferenceData = T.ValueSetString(required=False)
-    DatasetName = T.Name()
+    SASDatasetName = T.SASName()
     Domain = T.String()
+    Origin = T.String()
     Purpose = T.String()
-    CommentOID = T.OIDRef()
+    Comment = T.String()
     Description = T.ODMObject(element_class=Description)
-    ItemGroupRef = T.ODMListObject(element_class=ItemGroupRef)
     ItemRef = T.ODMListObject(element_class=ItemRef)
-    WorkflowRef = T.ODMListObject(element_class=WorkflowRef)
-    Origin = T.ODMListObject(element_class=Origin)
     Alias = T.ODMListObject(element_class=Alias)
 
     def __len__(self):
@@ -202,28 +198,28 @@ class ErrorMessage(OE.ODMElement):
 
 
 class RangeCheck(OE.ODMElement):
-    """ represents ODM v2.0 RangeCheck element that is a child of ItemDef and can serialize as JSON or XML """
     Comparator = T.ValueSetString(required=False)
-    SoftHard = T.ValueSetString()
+    SoftHard = T.ValueSetString(required=True)
     CheckValue = T.ODMListObject(element_class=CheckValue)
     FormalExpression = T.ODMListObject(element_class=FormalExpression)
+    MeasurementUnitRef = T.ODMObject(element_class=MeasurementUnitRef)
     ErrorMessage = T.ODMObject(element_class=ErrorMessage)
 
 
 class CodeListRef(OE.ODMElement):
-    CodeListOID = T.String("CodeListOID", required=True)
+    CodeListOID = T.OIDRef(required=True)
 
 
 class ItemDef(OE.ODMElement):
-    """ represents ODM v2.0 ItemDef and can serialize as JSON or XML - ordering of properties matters """
     OID = T.OID(required=True)
     Name = T.Name(required=True)
     DataType = T.ValueSetString(required=True)
     Length = T.PositiveInteger()
-    FractionDigits = T.NonNegativeInteger()
-    DatasetVarName = T.Name()
+    SignificantDigits = T.NonNegativeInteger()
+    SASFieldName = T.SASName()
     SDSVarName = T.SASName()
-    CommentOID = T.String()
+    Origin = T.String()
+    Comment = T.String()
     Description = T.ODMObject(element_class=Description)
     Question = T.ODMObject(element_class=Question)
     ExternalQuestion = T.ODMObject(element_class=ExternalQuestion)
@@ -238,7 +234,6 @@ class Decode(OE.ODMElement):
 
 
 class CodeListItem(OE.ODMElement):
-    """ represents ODM CodeListItem element that is a child of CodeList and can serialize as JSON or XML """
     CodedValue = T.String(required=True)
     Rank = T.Float(required=False)
     OrderNumber = T.Integer(required=False)
@@ -247,7 +242,6 @@ class CodeListItem(OE.ODMElement):
 
 
 class EnumeratedItem(OE.ODMElement):
-    """ represents ODM EnumeratedItem element that is a child of CodeList and can serialize as JSON or XML """
     CodedValue = T.String(required=True)
     Rank = T.Float(required=False)
     OrderNumber = T.Integer(required=False)
@@ -262,7 +256,6 @@ class ExternalCodeList(OE.ODMElement):
 
 
 class CodeList(OE.ODMElement):
-    """ represents ODM v1.3.2 CodeList element that can serialize as JSON or XML """
     OID = T.OID(required=True)
     Name = T.Name(required=True)
     DataType = T.ValueSetString(required=True)
@@ -274,6 +267,12 @@ class CodeList(OE.ODMElement):
     Alias = T.ODMListObject(element_class=Alias)
 
 
+class Presentation(OE.ODMElement):
+    OID = T.OID(required=True)
+    lang = T.String(required=False)
+    _content = T.String()
+
+
 class ConditionDef(OE.ODMElement):
     OID = T.OID(required=True)
     Name = T.Name(required=True)
@@ -282,200 +281,27 @@ class ConditionDef(OE.ODMElement):
     Alias = T.ODMListObject(element_class=Alias)
 
 
-class Parameter(OE.ODMElement):
-    Name = T.Name(required=True)
-    Definition = T.String()
-    DataType = T.ValueSetString(required=True)
-    OrderNumber = T.PositiveInteger()
-
-
-class ReturnValue(OE.ODMElement):
-    Name = T.Name(required=True)
-    Definition = T.String()
-    DataType = T.ValueSetString(required=True)
-    OrderNumber = T.PositiveInteger()
-
-
-class MethodSignature(OE.ODMElement):
-    Parameter = T.ODMListObject(element_class=Parameter)
-    ReturnValue = T.ODMListObject(element_class=ReturnValue)
-
-
 class MethodDef(OE.ODMElement):
-    """ represents ODM v2.0 MethodDef and can serialize as JSON or XML """
     OID = T.OID(required=True)
     Name = T.Name(required=True)
     Type = T.ValueSetString(required=True)
     Description = T.ODMObject(required=True, element_class=Description)
-    MethodSignature = T.ODMObject(element_class=MethodSignature)
     FormalExpression = T.ODMListObject(element_class=FormalExpression)
     Alias = T.ODMListObject(element_class=Alias)
 
 
-class StudyEventGroupRef(OE.ODMElement):
-    StudyEventGroupOID = T.OIDRef(required=True)
-    OrderNumber = T.Integer()
-    Mandatory = T.ValueSetString(required=True)
-    CollectionExceptionConditionOID = T.OIDRef()
-    Description = T.ODMObject(element_class=Description)
-
-
-class ExceptionEvent(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    ConditionOID = T.OIDRef(required=True)
-    Description = T.ODMObject(element_class=Description)
-    WorkflowRef = T.ODMObject(element_class=WorkflowRef)
-    StudyEventGroupRef = T.ODMListObject(element_class=StudyEventGroupRef)
-    StudyEventRef = T.ODMListObject(element_class=StudyEventRef)
-
-
-class WorkflowRef(OE.ODMElement):
-    WorkflowOID = T.OID(required=True)
-
-
-class Arm(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    Description = T.ODMObject(element_class=Description)
-    WorkflowRef = T.ODMObject(element_class=WorkflowRef)
-
-
-class Epoch(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    SequenceNumber = T.PositiveInteger(required=True)
-    Description = T.ODMObject(element_class=Description)
-
-
-class StudyStructure(OE.ODMElement):
-    Description = T.ODMObject(element_class=Description)
-    Arm = T.ODMListObject(element_class=Arm)
-    Epoch = T.ODMListObject(element_class=Epoch)
-    WorkflowRef = T.ODMListObject(element_class=WorkflowRef)
-
-
-class WorkflowStart(OE.ODMElement):
-    StartOID = T.OIDRef(required=True)
-
-
-class Transition(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    SourceOID = T.OIDRef(required=True)
-    TargetOID = T.OIDRef(required=True)
-    StartConditionOID = T.OIDRef()
-    EndConditionOID = T.OIDRef()
-
-
-class TargetTransition(OE.ODMElement):
-    TargetTransitionOID = T.OIDRef(required=True)
-    ConditionOID = T.OIDRef(required=True)
-
-
-class DefaultTransition(OE.ODMElement):
-    TargetTransitionOID = T.OIDRef(required=True)
-
-
-class Branching(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    Type = T.ValueSetString(required=True)
-    TargetTransition = T.ODMListObject(element_class=TargetTransition, required=True)
-    DefaultTransition = T.ODMListObject(element_class=DefaultTransition)
-
-
-class WorkflowEnd(OE.ODMElement):
-    EndOID = T.OIDRef(required=True)
-
-
-class WorkflowDef(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    Description = T.ODMObject(element_class=Description)
-    WorkflowStart = T.ODMObject(element_class=WorkflowStart, required=True)
-    Transition = T.ODMListObject(element_class=Transition)
-    Branching = T.ODMListObject(element_class=Branching)
-    WorkflowEnd = T.ODMListObject(element_class=WorkflowEnd, required=True)
-
-
-class AbsoluteTimingConstraint(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    StudyEventGroupOID = T.OIDRef()
-    StudyEventOID = T.OIDRef()
-    TimepointTarget = T.IncompleteDateTimeString(required=True)
-    TimepointPreWindow = T.DurationDateTimeString(required=True)
-    TimepointPostWindow = T.DurationDateTimeString(required=True)
-    Description = T.ODMObject(element_class=Description)
-
-
-class RelativeTimingConstraint(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    PredecessorStudyEventGroupOID = T.OIDRef()
-    PredecessorStudyEventOID = T.OIDRef()
-    SuccessorStudyEventGroupOID = T.OIDRef()
-    SuccessorStudyEventOID = T.OIDRef()
-    Type = T.ValueSetString()
-    TimepointRelativeTarget = T.DurationDateTimeString(required=True)
-    TimepointPreWindow = T.DurationDateTimeString(required=True)
-    TimepointPostWindow = T.DurationDateTimeString(required=True)
-    Description = T.ODMObject(element_class=Description)
-
-
-class TransitionTimingConstraint(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    TransitionOID = T.OIDRef(required=True)
-    TimepointRelativeTarget = T.DurationDateTimeString(required=True)
-    MethodOID = T.OIDRef()
-    TimepointPreWindow = T.DurationDateTimeString(required=True)
-    TimepointPostWindow = T.DurationDateTimeString(required=True)
-    Description = T.ODMObject(element_class=Description)
-
-
-class DurationTimingConstraint(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    StructuralElementOID = T.OIDRef(required=True)
-    DurationTarget = T.DurationDateTimeString(required=True)
-    DurationPreWindow = T.DurationDateTimeString(required=True)
-    DurationPostWindow = T.DurationDateTimeString(required=True)
-    Description = T.ODMObject(element_class=Description)
-
-
-class StudyTiming(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    AbsoluteTimingConstraint = T.ODMListObject(element_class=AbsoluteTimingConstraint)
-    RelativeTimingConstraint = T.ODMListObject(element_class=RelativeTimingConstraint)
-    TransitionTimingConstraint = T.ODMObject(element_class=TransitionTimingConstraint)
-    DurationTimingConstraint = T.ODMListObject(element_class=DurationTimingConstraint)
-
-
-class StudyEventGroupDef(OE.ODMElement):
-    OID = T.OID(required=True)
-    Name = T.Name(required=True)
-    ArmOID = T.OIDRef(required=True)
-    EpochOID = T.OIDRef(required=True)
-    Description = T.ODMObject(element_class=Description)
-
-
 class MetaDataVersion(OE.ODMElement):
     OID = T.OID(required=True)
     Name = T.Name(required=True)
-    Description = T.ODMObject(element_class=Description)
+    Description = T.String(required=False)
     Include = T.ODMObject(element_class=Include)
     Protocol = T.ODMObject(element_class=Protocol)
-    StudyStructure = T.ODMObject(element_class=StudyStructure)
-    WorkflowDef = T.ODMListObject(element_class=WorkflowDef)
-    StudyTiming = T.ODMObject(element_class=StudyTiming)
-    StudyEventGroupDef = T.ODMListObject(element_class=StudyEventGroupDef)
     StudyEventDef = T.ODMListObject(element_class=StudyEventDef)
+    FormDef = T.ODMListObject(element_class=FormDef)
     ItemGroupDef = T.ODMListObject(element_class=ItemGroupDef)
     ItemDef = T.ODMListObject(element_class=ItemDef)
     CodeList = T.ODMListObject(element_class=CodeList)
+    Presentation = T.ODMListObject(element_class=Presentation)
     ConditionDef = T.ODMListObject(element_class=ConditionDef)
     MethodDef = T.ODMListObject(element_class=MethodDef)
 
@@ -620,16 +446,191 @@ class AdminData(OE.ODMElement):
 
 
 class Study(OE.ODMElement):
-    """ v2.0 """
     OID = T.String(required=True)
-    StudyName = T.String(required=True)
-    ProtocolName = T.String(required=True)
-    Description = T.ODMObject(required=True, element_class=Description)
+    GlobalVariables = T.ODMObject(required=True, element_class=GlobalVariables)
+    BasicDefinitions = T.ODMObject(element_class=BasicDefinitions)
     MetaDataVersion = T.ODMListObject(required=False, element_class=MetaDataVersion)
 
 
+class UserRef(OE.ODMElement):
+    UserOID = T.OIDRef(required=True)
+
+
+class DateTimeStamp(OE.ODMElement):
+    _content = T.DateTimeString(required=True)
+
+
+class ReasonForChange(OE.ODMElement):
+    _content = T.String(required=True)
+
+
+class SourceID(OE.ODMElement):
+    _content = T.String(required=True)
+
+
+class AuditRecord(OE.ODMElement):
+    EditPoint = T.ValueSetString(required=False)
+    UsedImputationMethod = T.ValueSetString(required=False)
+    ID = T.ID(required=False)
+    UserRef = T.ODMObject(required=True, element_class=UserRef)
+    LocationRef = T.ODMObject(required=True, element_class=LocationRef)
+    DateTimeStamp = T.ODMObject(required=True, element_class=DateTimeStamp)
+    ReasonForChange = T.ODMObject(required=False, element_class=ReasonForChange)
+    SourceID = T.ODMObject(required=False, element_class=SourceID)
+
+
+class SignatureRef(OE.ODMElement):
+    SignatureOID = T.OIDRef(required=True)
+
+
+class Signature(OE.ODMElement):
+    ID = T.ID(required=True)
+    UserRef = T.ODMObject(required=True, element_class=UserRef)
+    LocationRef = T.ODMObject(required=True, element_class=LocationRef)
+    SignatureRef = T.ODMObject(required=True, element_class=SignatureRef)
+    DateTimeStamp = T.ODMObject(required=True, element_class=DateTimeStamp)
+
+
+class InvestigatorRef(OE.ODMElement):
+    UserOID = T.OIDRef(required=True)
+
+
+class SiteRef(OE.ODMElement):
+    LocationOID = T.OIDRef(required=True)
+
+
+class FlagValue(OE.ODMElement):
+    CodeListOID = T.OIDRef(required=True)
+    _content = T.String(required=True)
+
+
+class FlagType(OE.ODMElement):
+    CodeListOID = T.OIDRef(required=True)
+    _content = T.String(required=True)
+
+
+class Flag(OE.ODMElement):
+    FlagValue = T.ODMObject(required=True, element_class=FlagValue)
+    FlagType = T.ODMObject(element_class=FlagType)
+
+
+class Comment(OE.ODMElement):
+    SponsorOrSite = T.ValueSetString()
+    _content = T.String(required=True)
+
+
+class Annotation(OE.ODMElement):
+    SeqNum = T.Integer(required=True)
+    TransactionType = T.ValueSetString(required=False)
+    ID = T.ID(required=False)
+    Comment = T.ODMObject(required=False, element_class=Comment)
+    Flag = T.ODMListObject(element_class=Flag)
+
+
+class ItemData(OE.ODMElement):
+    ItemOID = T.OIDRef(required=True)
+    TransactionType = T.ValueSetString(required=False)
+    Value = T.String(required=False)
+    IsNull = T.ValueSetString(required=False)
+    AuditRecord = T.ODMObject(required=False, element_class=AuditRecord)
+    Signature = T.ODMObject(required=False, element_class=Signature)
+    MeasurementUnitRef = T.ODMObject(required=False, element_class=MeasurementUnitRef)
+    Annotation = T.ODMListObject(required=False, element_class=Annotation)
+
+
+class ItemGroupData(OE.ODMElement):
+    ItemGroupOID = T.OIDRef(required=True)
+    ItemGroupRepeatKey = T.String(required=False)
+    TransactionType = T.ValueSetString(required=False)
+    AuditRecord = T.ODMObject(required=False, element_class=AuditRecord)
+    Signature = T.ODMObject(required=False, element_class=Signature)
+    ArchiveLayout = T.ODMObject(required=False, element_class=ArchiveLayout)
+    Annotation = T.ODMListObject(required=False, element_class=Annotation)
+    ItemData = T.ODMListObject(required=False, element_class=ItemData)
+
+
+class FormData(OE.ODMElement):
+    FormOID = T.OIDRef(required=True)
+    FormRepeatKey = T.String(required=False)
+    TransactionType = T.ValueSetString(required=False)
+    AuditRecord = T.ODMObject(required=False, element_class=AuditRecord)
+    Signature = T.ODMObject(required=False, element_class=Signature)
+    ArchiveLayout = T.ODMObject(required=False, element_class=ArchiveLayout)
+    Annotation = T.ODMListObject(required=False, element_class=Annotation)
+    ItemGroupData = T.ODMListObject(required=False, element_class=ItemGroupData)
+
+
+class StudyEventData(OE.ODMElement):
+    StudyEventOID = T.OIDRef(required=True)
+    StudyEventRepeatKey = T.String(required=False)
+    TransactionType = T.ValueSetString(required=False)
+    AuditRecord = T.ODMObject(required=False, element_class=AuditRecord)
+    Signature = T.ODMObject(required=False, element_class=Signature)
+    Annotation = T.ODMListObject(required=False, element_class=Annotation)
+    FormData = T.ODMListObject(required=False, element_class=FormData)
+
+
+class SubjectData(OE.ODMElement):
+    SubjectKey = T.String(required=True)
+    TransactionType = T.ValueSetString(required=False)
+    AuditRecord = T.ODMObject(required=False, element_class=AuditRecord)
+    Signature = T.ODMObject(required=False, element_class=Signature)
+    InvestigatorRef = T.ODMObject(required=False, element_class=InvestigatorRef)
+    SiteRef = T.ODMObject(required=False, element_class=SiteRef)
+    Annotation = T.ODMListObject(required=False, element_class=Annotation)
+    StudyEventData = T.ODMListObject(required=False, element_class=StudyEventData)
+
+
+class AuditRecords(OE.ODMElement):
+    AuditRecord = T.ODMListObject(required=False, element_class=AuditRecord)
+
+
+class Signatures(OE.ODMElement):
+    Signature = T.ODMListObject(required=False, element_class=Signature)
+
+
+class Annotations(OE.ODMElement):
+    Annotation = T.ODMListObject(required=False, element_class=Annotation)
+
+
+class ClinicalData(OE.ODMElement):
+    StudyOID = T.OIDRef(required=True)
+    MetaDataVersionOID = T.OIDRef(required=True)
+    SubjectData = T.ODMListObject(element_class=SubjectData)
+    AuditRecords = T.ODMListObject(element_class=AuditRecords)
+    Signatures = T.ODMListObject(element_class=Signatures)
+    Annotations = T.ODMListObject(element_class=Annotations)
+
+
+class ReferenceData(OE.ODMElement):
+    StudyOID = T.OIDRef(required=True)
+    MetaDataVersionOID = T.OIDRef(required=True)
+    ItemGroupData = T.ODMListObject(element_class=ItemGroupData)
+    AuditRecords = T.ODMListObject(element_class=AuditRecords)
+    Signatures = T.ODMListObject(element_class=Signatures)
+    Annotations = T.ODMListObject(element_class=Annotations)
+
+
+class KeySet(OE.ODMElement):
+    StudyOID = T.OIDRef(required=True)
+    SubjectKey = T.String()
+    StudyEventOID = T.OIDRef()
+    StudyEventRepeatKey = T.String()
+    FormOID = T.OIDRef()
+    FormRepeatKey = T.String()
+    ItemGroupOID = T.OIDRef()
+    ItemGroupRepeatKey = T.String()
+    ItemOID = T.OIDRef()
+
+
+class Association(OE.ODMElement):
+    StudyOID = T.OIDRef(required=True)
+    MetaDataVersionOID = T.OIDRef(required=True)
+    KeySet = T.ODMListObject(required=True, element_class=KeySet)
+    Annotation = T.ODMObject(required=True, element_class=Annotation)
+
+
 class ODM(OE.ODMElement):
-    """ v2.0 """
     Description = T.String(required=False)
     FileType = T.ValueSetString(required=True)
     Granularity = T.ValueSetString(required=False)
@@ -642,11 +643,10 @@ class ODM(OE.ODMElement):
     Originator = T.String(required=False)
     SourceSystem = T.String(required=False)
     SourceSystemVersion = T.String(required=False)
+    schemaLocation = T.String(required=False, namespace="xs")
     ID = T.ID()
     Study = T.ODMListObject(element_class=Study)
     AdminData = T.ODMListObject(element_class=AdminData)
-    #ReferenceData = T.ODMListObject(element_class=referencedata.ReferenceData)
-    #ClinicalData = T.ODMListObject(element_class=clinicaldata.ClinicalData)
-    #Association = T.ODMListObject(element_class=association.Association)
-    #ds_Signature = T.ODMListObject(element_class=dssignature.ds_Signature)
-
+    ReferenceData = T.ODMListObject(element_class=ReferenceData)
+    ClinicalData = T.ODMListObject(element_class=ClinicalData)
+    Association = T.ODMListObject(element_class=Association)
